==> cluster_experiments-0.10.4.tar.gz: cluster_experiments-0.10.4/cluster_experiments/__init__.py <==
from cluster_experiments.cupac import EmptyRegressor, TargetAggregation
from cluster_experiments.experiment_analysis import (
    ClusteredOLSAnalysis,
    ExperimentAnalysis,
    GeeExperimentAnalysis,
    MLMExperimentAnalysis,
    OLSAnalysis,
    PairedTTestClusteredAnalysis,
    TTestClusteredAnalysis,
)
from cluster_experiments.perturbator import (
    BetaRelativePerturbator,
    BetaRelativePositivePerturbator,
    BinaryPerturbator,
    ConstantPerturbator,
    NormalPerturbator,
    Perturbator,
    RelativePositivePerturbator,
    SegmentedBetaRelativePerturbator,
    UniformPerturbator,
)
from cluster_experiments.power_analysis import PowerAnalysis
from cluster_experiments.power_config import PowerConfig
from cluster_experiments.random_splitter import (
    BalancedClusteredSplitter,
    BalancedSwitchbackSplitter,
    ClusteredSplitter,
    NonClusteredSplitter,
    RandomSplitter,
    RepeatedSampler,
    StratifiedClusteredSplitter,
    StratifiedSwitchbackSplitter,
    SwitchbackSplitter,
)
from cluster_experiments.washover import ConstantWashover, EmptyWashover, Washover

__all__ = [
    "ExperimentAnalysis",
    "GeeExperimentAnalysis",
    "OLSAnalysis",
    "BinaryPerturbator",
    "Perturbator",
    "ConstantPerturbator",
    "UniformPerturbator",
    "RelativePositivePerturbator",
    "NormalPerturbator",
    "BetaRelativePositivePerturbator",
    "BetaRelativePerturbator",
    "SegmentedBetaRelativePerturbator",
    "PowerAnalysis",
    "PowerConfig",
    "EmptyRegressor",
    "TargetAggregation",
    "BalancedClusteredSplitter",
    "ClusteredSplitter",
    "RandomSplitter",
    "NonClusteredSplitter",
    "StratifiedClusteredSplitter",
    "SwitchbackSplitter",
    "BalancedSwitchbackSplitter",
    "StratifiedSwitchbackSplitter",
    "RepeatedSampler",
    "ClusteredOLSAnalysis",
    "TTestClusteredAnalysis",
    "PairedTTestClusteredAnalysis",
    "EmptyWashover",
    "ConstantWashover",
    "Washover",
    "MLMExperimentAnalysis",
]

==> cluster_experiments-0.19.0.tar.gz: cluster_experiments-0.19.0/cluster_experiments/__init__.py <==
from cluster_experiments.cupac import EmptyRegressor, TargetAggregation
from cluster_experiments.experiment_analysis import (
    ClusteredOLSAnalysis,
    ExperimentAnalysis,
    GeeExperimentAnalysis,
    MLMExperimentAnalysis,
    OLSAnalysis,
    PairedTTestClusteredAnalysis,
    SyntheticControlAnalysis,
    TTestClusteredAnalysis,
)
from cluster_experiments.perturbator import (
    BetaRelativePerturbator,
    BetaRelativePositivePerturbator,
    BinaryPerturbator,
    ConstantPerturbator,
    NormalPerturbator,
    Perturbator,
    RelativePositivePerturbator,
    SegmentedBetaRelativePerturbator,
    UniformPerturbator,
)
from cluster_experiments.power_analysis import NormalPowerAnalysis, PowerAnalysis
from cluster_experiments.power_config import PowerConfig
from cluster_experiments.random_splitter import (
    BalancedClusteredSplitter,
    BalancedSwitchbackSplitter,
    ClusteredSplitter,
    FixedSizeClusteredSplitter,
    NonClusteredSplitter,
    RandomSplitter,
    RepeatedSampler,
    StratifiedClusteredSplitter,
    StratifiedSwitchbackSplitter,
    SwitchbackSplitter,
)
from cluster_experiments.washover import ConstantWashover, EmptyWashover, Washover

__all__ = [
    "ExperimentAnalysis",
    "GeeExperimentAnalysis",
    "OLSAnalysis",
    "BinaryPerturbator",
    "Perturbator",
    "ConstantPerturbator",
    "UniformPerturbator",
    "RelativePositivePerturbator",
    "NormalPerturbator",
    "BetaRelativePositivePerturbator",
    "BetaRelativePerturbator",
    "SegmentedBetaRelativePerturbator",
    "PowerAnalysis",
    "NormalPowerAnalysis",
    "PowerConfig",
    "EmptyRegressor",
    "TargetAggregation",
    "BalancedClusteredSplitter",
    "ClusteredSplitter",
    "RandomSplitter",
    "NonClusteredSplitter",
    "StratifiedClusteredSplitter",
    "SwitchbackSplitter",
    "BalancedSwitchbackSplitter",
    "StratifiedSwitchbackSplitter",
    "RepeatedSampler",
    "ClusteredOLSAnalysis",
    "TTestClusteredAnalysis",
    "PairedTTestClusteredAnalysis",
    "EmptyWashover",
    "ConstantWashover",
    "Washover",
    "MLMExperimentAnalysis",
    "SyntheticControlAnalysis",
    "FixedSizeClusteredSplitter",
]
